==> xfce4-weather-plugin_0.6.0.orig.tar.gz: xfce4-weather-plugin-0.6.0/panel-plugin/weather-icon.c <==
/*  $Id: weather-icon.c 2366 2007-01-15 19:10:23Z nick $
 *
 *  Copyright (c) 2003-2007 Xfce Development Team
 * 
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <glib.h>
#include <gtk/gtk.h>

#include "weather-icon.h"



#define DEFAULT_W_THEME "liquid"



GdkPixbuf *
get_icon (const gchar *number,
          GtkIconSize  size)
{
  GdkPixbuf *image = NULL;
  gchar     *filename;
  gint       width, height;

  gtk_icon_size_lookup (size, &width, &height);

  filename = g_strdup_printf ("%s%s%s%s%s.png",
                              THEMESDIR, G_DIR_SEPARATOR_S,
                              DEFAULT_W_THEME, G_DIR_SEPARATOR_S, number);

  image = gdk_pixbuf_new_from_file_at_scale (filename,
                                             width, height, TRUE, NULL);

  g_free (filename);

  if (!image)
    g_warning ("Weather Plugin: No image found");

  return image;
}

==> xfce4-weather-plugin_0.7.3.orig.tar.gz: xfce4-weather-plugin-0.7.3/panel-plugin/weather-icon.c <==
/*  $Id: weather-icon.c 7550 2009-06-13 07:46:50Z colin $
 *
 *  Copyright (c) 2003-2007 Xfce Development Team
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <glib.h>
#include <gtk/gtk.h>

#include "weather-icon.h"



#define DEFAULT_W_THEME "liquid"



GdkPixbuf *
get_icon (const gchar *number,
          gint         size)
{
  GdkPixbuf *image = NULL;
  gchar     *filename;

  filename = g_strdup_printf ("%s" G_DIR_SEPARATOR_S "%s" G_DIR_SEPARATOR_S "%s.png",
                              THEMESDIR, DEFAULT_W_THEME, number);

  image = gdk_pixbuf_new_from_file_at_scale (filename, size, size, TRUE, NULL);

  if (G_UNLIKELY (!image)) {
    g_warning ("Unable to open image: %s", filename);
    if (number && strcmp(number, "99")) {
      g_free(filename);
      return get_icon("99", size);
    }
  }
  g_free (filename);

  return image;
}
